# Generated by Django 2.1 on 2019-05-07 14:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0085_auto_20190506_1028'),
        ('djconnectwise', '0085_auto_20190430_1004'),
    ]

    operations = [
    ]



# Generated by Django 3.1.7 on 2021-07-23 11:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0152_auto_20210722_1224'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='tasks_completed',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='tasks_total',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.14 on 2020-09-17 19:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0123_project_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='lag_days',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='lag_non_working_days_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='predecessor_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='predecessor_type',
            field=models.CharField(blank=True, choices=[('Ticket', 'Ticket'), ('Phase', 'Phase')], max_length=10, null=True),
        ),
    ]



# Generated by Django 3.1.7 on 2021-07-28 14:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0154_auto_20210726_1252'),
        ('djconnectwise', '0153_auto_20210723_1104'),
    ]

    operations = [
    ]



# Generated by Django 2.0 on 2019-01-31 22:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0082_auto_20190125_1109'),
    ]

    operations = [
        migrations.DeleteModel(
            name='CallBackEntry',
        ),
    ]



# Generated by Django 2.0 on 2018-12-03 10:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0077_item_subtype_type'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subtype',
            options={'verbose_name': 'Subtype', 'verbose_name_plural': 'Subtypes'},
        ),
    ]



# Generated by Django 2.1.14 on 2020-06-09 15:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0116_auto_20200522_1107'),
    ]

    operations = [
        migrations.AddField(
            model_name='connectwiseboard',
            name='project_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='project',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.ConnectWiseBoard'),
        ),
        migrations.AddField(
            model_name='project',
            name='percent_complete',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=3, null=True),
        ),
    ]



# Generated by Django 3.1.5 on 2021-01-11 16:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0142_communicationtype_communicationtypetracker'),
    ]

    operations = [
        migrations.AddField(
            model_name='contactcommunication',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.communicationtype'),
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-08 20:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0129_auto_20201005_1054'),
    ]

    operations = [
        migrations.CreateModel(
            name='ActivityStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activitystatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activitystatus',),
        ),
        migrations.CreateModel(
            name='ActivityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activity',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activity',),
        ),
        migrations.CreateModel(
            name='ActivityTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activitytype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activitytype',),
        ),
        migrations.CreateModel(
            name='AgreementTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_agreement',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.agreement',),
        ),
        migrations.CreateModel(
            name='BoardStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_boardstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.boardstatus',),
        ),
        migrations.CreateModel(
            name='CalendarTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_calendar',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.calendar',),
        ),
        migrations.CreateModel(
            name='CompanyStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companystatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companystatus',),
        ),
        migrations.CreateModel(
            name='CompanyTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_company',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.company',),
        ),
        migrations.CreateModel(
            name='CompanyTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companytype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companytype',),
        ),
        migrations.CreateModel(
            name='ConnectWiseBoardTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_connectwiseboard',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.connectwiseboard',),
        ),
        migrations.CreateModel(
            name='HolidayListTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_holidaylist',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.holidaylist',),
        ),
        migrations.CreateModel(
            name='HolidayTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_holiday',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.holiday',),
        ),
        migrations.CreateModel(
            name='ItemTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_item',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.item',),
        ),
        migrations.CreateModel(
            name='LocationTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_location',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.location',),
        ),
        migrations.CreateModel(
            name='MemberTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_member',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.member',),
        ),
        migrations.CreateModel(
            name='MyCompanyOtherTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_mycompanyother',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.mycompanyother',),
        ),
        migrations.CreateModel(
            name='OpportunityNoteTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitynote',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitynote',),
        ),
        migrations.CreateModel(
            name='OpportunityPriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitypriority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitypriority',),
        ),
        migrations.CreateModel(
            name='OpportunityStageTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitystage',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitystage',),
        ),
        migrations.CreateModel(
            name='OpportunityStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitystatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitystatus',),
        ),
        migrations.CreateModel(
            name='OpportunityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunity',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunity',),
        ),
        migrations.CreateModel(
            name='OpportunityTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitytype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitytype',),
        ),
        migrations.CreateModel(
            name='ProjectPhaseTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectphase',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectphase',),
        ),
        migrations.CreateModel(
            name='ProjectStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectstatus',),
        ),
        migrations.CreateModel(
            name='ProjectTeamMemberTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectteammember',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectteammember',),
        ),
        migrations.CreateModel(
            name='ProjectTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_project',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.project',),
        ),
        migrations.CreateModel(
            name='ProjectTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projecttype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projecttype',),
        ),
        migrations.CreateModel(
            name='SalesProbabilityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_salesprobability',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.salesprobability',),
        ),
        migrations.CreateModel(
            name='ScheduleEntryTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_scheduleentry',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.scheduleentry',),
        ),
        migrations.CreateModel(
            name='ScheduleStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_schedulestatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.schedulestatus',),
        ),
        migrations.CreateModel(
            name='ScheduleTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_scheduletype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.scheduletype',),
        ),
        migrations.CreateModel(
            name='ServiceNoteTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_servicenote',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.servicenote',),
        ),
        migrations.CreateModel(
            name='SlaPriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_slapriority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.slapriority',),
        ),
        migrations.CreateModel(
            name='SlaTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_sla',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.sla',),
        ),
        migrations.CreateModel(
            name='SubTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_subtype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.subtype',),
        ),
        migrations.CreateModel(
            name='TeamTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_team',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.team',),
        ),
        migrations.CreateModel(
            name='TerritoryTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_territory',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.territory',),
        ),
        migrations.CreateModel(
            name='TicketPriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_ticketpriority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.ticketpriority',),
        ),
        migrations.CreateModel(
            name='TicketTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_ticket',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.ticket',),
        ),
        migrations.CreateModel(
            name='TimeEntryTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_timeentry',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.timeentry',),
        ),
        migrations.CreateModel(
            name='TypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_type',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.type',),
        ),
        migrations.CreateModel(
            name='WorkRoleTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_workrole',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.workrole',),
        ),
        migrations.CreateModel(
            name='WorkTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_worktype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.worktype',),
        ),
    ]



# Generated by Django 2.0 on 2018-12-10 09:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0079_auto_20181203_1606'),
    ]

    operations = [
        migrations.AlterField(
            model_name='member',
            name='last_name',
            field=models.CharField(max_length=30, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0013_auto_20170403_1203'),
    ]

    operations = [
        migrations.AddField(
            model_name='company',
            name='status',
            field=models.ForeignKey(blank=True, null=True, to='djconnectwise.CompanyStatus', on_delete=models.SET_NULL),
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-15 17:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0132_activityudf_opportunityudf_projectudf_ticketudf'),
    ]

    operations = [
        migrations.CreateModel(
            name='ActivityUDFTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activityudf',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activityudf',),
        ),
        migrations.CreateModel(
            name='OpportunityUDFTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunityudf',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunityudf',),
        ),
        migrations.CreateModel(
            name='ProjectUDFTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectudf',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectudf',),
        ),
        migrations.CreateModel(
            name='TicketUDFTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_ticketudf',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.ticketudf',),
        ),
    ]



# Generated by Django 2.1 on 2019-07-12 14:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0090_auto_20190711_1114'),
    ]

    operations = [
        migrations.AddField(
            model_name='worktype',
            name='bill_time',
            field=models.CharField(blank=True, choices=[('Billable', 'Billable'), ('DoNotBill', 'Do Not Bill'), ('NoCharge', 'No Charge')], max_length=50, null=True),
        ),
    ]



# Generated by Django 2.0 on 2018-09-10 16:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0074_auto_20180827_1241'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timeentry',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.Company'),
        ),
    ]



# Generated by Django 2.1.11 on 2019-09-09 11:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0109_ticket_phase'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.Company'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0031_auto_20170607_2234'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='record_type',
            field=models.CharField(null=True, blank=True, db_index=True, max_length=250, choices=[('ServiceTicket', 'Service Ticket'), ('ProjectTicket', 'Project Ticket'), ('ProjectIssue', 'Project Issue')]),
        ),
    ]



# Generated by Django 2.1.14 on 2020-07-21 16:17

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0119_auto_20200624_1028'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProjectTeamMember',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('start_date', models.DateTimeField(blank=True, null=True)),
                ('end_date', models.DateTimeField(blank=True, null=True)),
                ('member', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.Member')),
                ('project', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.Project')),
                ('work_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.WorkRole')),
            ],
            options={
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='project',
            name='team_members',
            field=models.ManyToManyField(through='djconnectwise.ProjectTeamMember', to='djconnectwise.Member'),
        ),
    ]



# Generated by Django 2.0 on 2019-04-30 10:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0084_auto_20190404_1532'),
    ]

    operations = [
        migrations.AddField(
            model_name='timeentry',
            name='email_cc_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='timeentry',
            name='email_contact_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='timeentry',
            name='email_resource_flag',
            field=models.BooleanField(default=False),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0016_auto_20170404_1504'),
    ]

    operations = [
        migrations.AlterField(
            model_name='member',
            name='created',
            field=models.DateTimeField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='member',
            name='modified',
            field=models.DateTimeField(auto_now=True),
        ),
    ]



# Generated by Django 3.1.7 on 2021-07-26 12:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0153_auto_20210723_1018'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contact',
            options={'ordering': ('first_name', 'last_name')},
        ),
    ]



# Generated by Django 3.1 on 2020-09-24 13:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0125_auto_20200923_0952'),
    ]

    operations = [
        migrations.AlterField(
            model_name='activity',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.company'),
        ),
        migrations.AlterField(
            model_name='boardstatus',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.connectwiseboard'),
        ),
        migrations.AlterField(
            model_name='project',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.connectwiseboard'),
        ),
        migrations.AlterField(
            model_name='scheduleentry',
            name='activity_object',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.activity'),
        ),
        migrations.AlterField(
            model_name='scheduleentry',
            name='member',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.member'),
        ),
        migrations.AlterField(
            model_name='scheduleentry',
            name='ticket_object',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.ticket'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.connectwiseboard'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='project_tickets', to='djconnectwise.project'),
        ),
        migrations.AlterField(
            model_name='timeentry',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.company'),
        ),
    ]



# Generated by Django 3.1.2 on 2020-12-15 13:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0140_auto_20201209_1033'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='contact',
            name='address_line1',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='address_line2',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='city',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='state_identifier',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='zip',
        ),
    ]
